aboutsummaryrefslogtreecommitdiff
path: root/www/chromium/files/patch-content_browser_devtools_protocol_system__info__handler.cc
diff options
context:
space:
mode:
Diffstat (limited to 'www/chromium/files/patch-content_browser_devtools_protocol_system__info__handler.cc')
-rw-r--r--www/chromium/files/patch-content_browser_devtools_protocol_system__info__handler.cc14
1 files changed, 8 insertions, 6 deletions
diff --git a/www/chromium/files/patch-content_browser_devtools_protocol_system__info__handler.cc b/www/chromium/files/patch-content_browser_devtools_protocol_system__info__handler.cc
index f08535e77efe..27f06f39f69b 100644
--- a/www/chromium/files/patch-content_browser_devtools_protocol_system__info__handler.cc
+++ b/www/chromium/files/patch-content_browser_devtools_protocol_system__info__handler.cc
@@ -1,11 +1,13 @@
---- content/browser/devtools/protocol/system_info_handler.cc.orig 2020-11-13 06:36:42 UTC
+--- content/browser/devtools/protocol/system_info_handler.cc.orig 2021-03-12 23:57:24 UTC
+++ content/browser/devtools/protocol/system_info_handler.cc
-@@ -47,7 +47,7 @@ std::unique_ptr<SystemInfo::Size> GfxSizeToSystemInfoS
- // Give the GPU process a few seconds to provide GPU info.
- // Linux Debug builds need more time -- see Issue 796437 and 1046598.
+@@ -49,8 +49,8 @@ std::unique_ptr<SystemInfo::Size> GfxSizeToSystemInfoS
+ // Linux and Mac Debug builds need more time -- see Issue 796437, 1046598, and
+ // 1153667.
// Windows builds need more time -- see Issue 873112 and 1004472.
--#if ((defined(OS_LINUX) || defined(OS_CHROMEOS)) && !defined(NDEBUG)) || \
-+#if ((defined(OS_LINUX) || defined(OS_CHROMEOS) || defined(OS_BSD)) && !defined(NDEBUG)) || \
+-#if ((defined(OS_LINUX) || defined(OS_CHROMEOS) || defined(OS_MAC)) && \
+- !defined(NDEBUG)) || \
++#if ((defined(OS_LINUX) || defined(OS_CHROMEOS) || defined(OS_MAC) || defined(OS_BSD)) && \
++ !defined(NDEBUG)) || \
defined(OS_WIN)
const int kGPUInfoWatchdogTimeoutMs = 30000;
#else